@@ -90,8 +90,8 @@ class RemoteResponseGenerator(Resource):
         app.logger.info("result: %s", response)
         return response
 
-    def _set_response_generator_controller(self, rg_state: ResponseGeneratorUpdateState = None,
-                                           rg_apl: ResponseGeneratorAPLBuilder = None) -> None:
+    def _set_response_generator_controller(self, rg_state: ResponseGeneratorUpdateState,
+                                           rg_apl: ResponseGeneratorAPLBuilder) -> None:
         if self.response_generator_controller is None \
                 and self.args is not None \
                 and rg_state is not None \
